This folder contains integration tests, testing how the scraper behaves:

- with a real minimal mbtiles file
- from end-to-end

They are targetted at being ran from scraper Docker image from Github workflow(s).
